@@ -1,7 +1,7 @@
 /*****************************************************************************\
   Hbpl1.cpp : Implementation for the Hbpl1 class
 
-  Copyright (c) 1996 - 2012, Hewlett-Packard Co.
+  Copyright (c) 1996 - 2015, HP Co.
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -12,7 +12,7 @@
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
-  3. Neither the name of Hewlett-Packard nor the names of its
+  3. Neither the name of HP nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
@@ -60,7 +60,7 @@ Hbpl1::Hbpl1 () : Encapsulator ()
     m_ColorMode = COLORTYPE_BOTH; //Grayscale
     m_ColorTheme = NONE;
 
-    m_hHPLibHandle = load_plugin_library(UTILS_PRINT_PLUGIN_LIBRARY, PRNT_PLUGIN_HBPL1);
+    /*m_hHPLibHandle = load_plugin_library(UTILS_PRINT_PLUGIN_LIBRARY, PRNT_PLUGIN_HBPL1);
     if (m_hHPLibHandle)
     {
         dlerror ();
@@ -71,8 +71,12 @@ Hbpl1::Hbpl1 () : Encapsulator ()
 
         if ((m_pHbpl1Wrapper = fptr_create(this)) == NULL)
              m_init = false;
-    }
-
+    }*/
+    m_pHbpl1Wrapper = new Hbpl1Wrapper(this);
+    if(m_pHbpl1Wrapper == NULL)
+	m_init = false;
+    else
+	m_init = true;
 }
 
 Hbpl1::~Hbpl1()
@@ -89,8 +93,8 @@ Hbpl1::~Hbpl1()
         if(fptr_destroy)
             fptr_destroy( m_pHbpl1Wrapper );
 
-        unload_library(m_hHPLibHandle);
-        m_hHPLibHandle = NULL;
+        //unload_library(m_hHPLibHandle);
+        //m_hHPLibHandle = NULL;
     }
 }
 
